@@ -339,6 +339,8 @@ class Deriver(object):
 
         for seed in self.data.seed_smiles:
             children = selfies_scanner(parent_smiles=seed)
+            if len(children) == 0:
+                continue
             self.data.heritage[seed] += children
 
             filtered_children = apply_filter(filter_params,
@@ -526,6 +528,9 @@ class Deriver(object):
 
         # get the "maximum number of children" per fragment
         n_seed_frags = len(self.data.seed_frags)
+        if n_seed_frags == 0:
+            logger.warning("No seed fragments! Cannot derive brics from these seeds.")
+            return [], {}
 
         if self.data.filter:
             filter_params = self.data.filter_params
